@@ -9,10 +9,12 @@ import (
 	"github.com/urfave/cli/v2"
 )
 
-// GenSchema is struct for running 'GenSchema' command.
+var _ Action = (*GenSchema)(nil)
+
+// GenSchema is a struct for running 'GenSchema' command.
 type GenSchema struct{}
 
-// Run is main function for 'GenSchema' command.
+// Run is the main function for 'GenSchema' command.
 func (i *GenSchema) Run(ctx context.Context) error {
 	s, err := json.Marshal(plan.GenSchema())
 	if err != nil {
@@ -28,7 +30,7 @@ func (i *GenSchema) Run(ctx context.Context) error {
 func (i *GenSchema) Cmd() *cli.Command {
 	return &cli.Command{
 		Name:   "schema",
-		Usage:  "Generate helmwave json schema",
+		Usage:  "generate json schema",
 		Flags:  i.flags(),
 		Action: toCtx(i.Run),
 	}
