@@ -2,5 +2,5 @@ package helper
 
 const (
 	// RootAnnoName is prefix for all kubedog annotations.
-	RootAnnoName = "helmwave.dev/"
+	RootAnnoName = "helmwave.app/"
 )
