@@ -10,33 +10,44 @@ import (
 	log "github.com/sirupsen/logrus"
 )
 
-func (p *Plan) Status(names []string) error {
+// Status renders status table for list of releases names.
+func (p *Plan) Status(names ...string) error {
 	return status(p.body.Releases, names)
 }
 
-func status(all []*release.Config, names []string) error {
+func status(all []release.Config, names []string) error {
 	r := all
 
 	if len(names) > 0 {
 		sort.Strings(names)
-		r = make([]*release.Config, 0, len(all))
+		r = make([]release.Config, 0, len(all))
 
 		for _, rel := range all {
-			if helper.Contains(string(rel.Uniq()), names) {
+			if helper.Contains(rel.Uniq().String(), names) {
 				r = append(r, rel)
 			}
 		}
 	}
 
 	for _, rel := range r {
+		l := rel.Logger()
+
 		s, err := rel.Status()
 		if err != nil {
-			log.Errorf("Failed to get s of %s: %v", rel.Uniq(), err)
+			l.Errorf("Failed to get status: %v", err)
+
 			continue
 		}
 
-		labels, _ := json.Marshal(s.Labels)
-		values, _ := json.Marshal(s.Config)
+		labels, err := json.Marshal(s.Labels)
+		if err != nil {
+			l.Errorf("Failed to get labels: %v", err)
+		}
+
+		values, err := json.Marshal(s.Config)
+		if err != nil {
+			l.Errorf("Failed to get values: %v", err)
+		}
 
 		log.WithFields(log.Fields{
 			"name":          s.Name,
@@ -45,14 +56,14 @@ func status(all []*release.Config, names []string) error {
 			"last deployed": s.Info.LastDeployed,
 			"status":        s.Info.Status,
 			"revision":      s.Version,
-		}).Infof("General s of %s", rel.Uniq())
+		}).Infof("General status of %s", rel.Uniq())
 
 		log.WithFields(log.Fields{
 			"notes":         s.Info.Notes,
 			"labels":        string(labels),
 			"chart sources": s.Chart.Metadata.Sources,
 			"values":        string(values),
-		}).Debugf("Debug s of %s", rel.Uniq())
+		}).Debugf("Debug status of %s", rel.Uniq())
 
 		log.WithFields(log.Fields{
 			"hooks":    s.Hooks,
