@@ -1,16 +1,10 @@
 package release
 
 import (
-	"errors"
-	"fmt"
-
 	"github.com/helmwave/helmwave/pkg/release/uniqname"
 	"gopkg.in/yaml.v3"
 )
 
-// ErrMissingDependency is returned when values can't be used and are skipped.
-var ErrMissingDependency = errors.New("dependency is missing")
-
 type DependencyType int
 
 const (
@@ -21,11 +15,11 @@ const (
 
 // DependsOnReference is used to store release dependencies.
 //
-// nolintlint:lll
+//nolint:lll
 type DependsOnReference struct {
-	Name     string `yaml:"name" json:"name" jsonschema:"description=Uniqname (or just name if in same namespace) of dependency release"`                    //nolint:lll
-	Tag      string `yaml:"tag,omitempty" json:"tag,omitempty" jsonschema:"description=All available releases with the tag will be applied as dependencies"` //nolint:lll
-	Optional bool   `yaml:"optional" json:"optional" jsonschema:"description=Whether the dependency is required to be present in plan,default=false"`        //nolint:lll
+	Name     string `yaml:"name" json:"name" jsonschema:"description=Uniqname (or just name if in same namespace) of dependency release,oneof_required=name"`
+	Tag      string `yaml:"tag,omitempty" json:"tag,omitempty" jsonschema:"description=All available releases with the tag will be applied as dependencies,oneof_required=tag"`
+	Optional bool   `yaml:"optional" json:"optional" jsonschema:"description=Whether the dependency is required to be present in plan,default=false"`
 }
 
 // UnmarshalYAML is used to implement InterfaceUnmarshaler interface of gopkg.in/yaml.v3.
@@ -39,11 +33,11 @@ func (d *DependsOnReference) UnmarshalYAML(node *yaml.Node) error {
 	case yaml.MappingNode:
 		err = node.Decode((*raw)(d))
 	default:
-		err = fmt.Errorf("unknown format")
+		err = ErrUnknownFormat
 	}
 
 	if err != nil {
-		return fmt.Errorf("failed to decode depends_on reference %q from YAML: %w", node.Value, err)
+		return NewYAMLDecodeDependsOnError(node.Value, err)
 	}
 
 	return nil
