@@ -6,6 +6,7 @@ import (
 
 	"github.com/helmwave/helmwave/pkg/helper"
 	"github.com/helmwave/helmwave/pkg/log"
+	"github.com/helmwave/helmwave/pkg/monitor"
 	"github.com/helmwave/helmwave/pkg/release/uniqname"
 	"github.com/invopop/jsonschema"
 	"gopkg.in/yaml.v3"
@@ -45,6 +46,9 @@ type Config interface {
 	Cfg() *action.Configuration
 	HooksDisabled() bool
 	OfflineKubeVersion() *chartutil.KubeVersion
+	Validate() error
+	Monitors() []MonitorReference
+	NotifyMonitorsFailed(context.Context, ...monitor.Config)
 }
 
 // Configs type of array Config.
@@ -67,8 +71,25 @@ func (r *Configs) UnmarshalYAML(node *yaml.Node) error {
 }
 
 func (Configs) JSONSchema() *jsonschema.Schema {
-	r := &jsonschema.Reflector{DoNotReference: true}
+	r := &jsonschema.Reflector{
+		DoNotReference:             true,
+		RequiredFromJSONSchemaTags: true,
+	}
 	var l []*config
 
 	return r.Reflect(&l)
 }
+
+func (r Configs) Contains(rel Config) (Config, bool) {
+	return r.ContainsUniq(rel.Uniq())
+}
+
+func (r Configs) ContainsUniq(uniq uniqname.UniqName) (Config, bool) {
+	for _, rel := range r {
+		if rel.Uniq().Equal(uniq) {
+			return rel, true
+		}
+	}
+
+	return nil, false
+}
